rad.brief <-
function(ref=NULL, brief=TRUE, ...)

  Read(ref, brief=TRUE, ...)
